@@ -426,359 +426,11 @@ namespace massXpert
 	return;
       }
 
-    const PolChemDef *polChemDef = mp_polymer->polChemDef();
-    const QList <Atom *> &atomRefList = polChemDef->atomList();    
-    Formula formula;
-  
-    setCursor(Qt::WaitCursor);
-  
-    for (int iter = 0; iter < m_coordinateList.size(); ++iter)
-      {
-	// New coordinates instance we are iterating into.
-	Coordinates *coordinates = m_coordinateList.at(iter);
-	
-	for(int jter = coordinates->start() ; 
-	     jter < coordinates->end() + 1; ++jter)
-	  {
-	    const Monomer *iterMonomer = mp_polymer->at(jter);
-	    Q_ASSERT(iterMonomer);
-      
-	    // Set the formula of the new monomer in the same formula
-	    // instance.
-	    formula.setFormula(iterMonomer->formula());
-
-	    // Incrementally account for the new formula in the same
-	    // atomcount list in the formula.
-	    if (formula.accountAtoms(atomRefList, 1) == false)
-	      {
-		setCursor(Qt::ArrowCursor);
-	  
-		QMessageBox::warning 
-		 (0, 
-		   tr("massXpert - Compositions"),
-		   tr("Failed accounting one monomer formula."),
-		   QMessageBox::Ok);
-	  
-		return;
-	      }
-
-	    if (mp_calcOptions->monomerEntities() & MXT_MONOMER_CHEMENT_MODIF)
-	      {
-		if(iterMonomer->isModified())
-		  {
-		    for (int jter = 0; 
-			 jter < iterMonomer->modifList()->size();
-			 ++jter)
-		      {
-			Modif *modif = iterMonomer->modifList()->at(jter);
-
-			formula.setFormula(modif->formula());
-		  
-			// Incrementally account for the new formula in the same
-			// atomcount list in the formula.
-			if(formula.accountAtoms(atomRefList, 1) == false)
-			  {
-			    setCursor(Qt::ArrowCursor);
-		      
-			    QMessageBox::warning 
-			     (0, 
-			       tr("massXpert - Compositions"),
-			       tr("Failed accounting one monomer modification."),
-			       QMessageBox::Ok);
-		      
-			    return;
-			  }
-		      }
-		  }
-	      }
-	  }
-	// End of for (int jter = m_startIndex ; jter < m_endIndex + 1;
-	// ++jter)
-      }
-    
-//     qDebug() << __FILE__ << __LINE__
-// 	      << "Formula after accounting for all the residual chains:"
-// 	      << formula.elementalComposition();
-    
-    // We now have to account for the left/right cappings. However,
-    // when there are multiple region selections(that is multiple
-    // Coordinate elements in the calcOptions.coordinateList()) it is
-    // necessary to know if the user wants each of these Coordinates
-    // to be considered real oligomers(each one with its left/right
-    // caps) or as residual chains. Thus there are two cases:
-
-    // 1. Each Coordinates item should be considered an oligomer
-    //(SelectionType is SELECTION_TYPE_OLIGOMERS), thus for each item
-    // the left and right caps should be accounted for. This is
-    // typically the case when the user selects multiple regions to
-    // compute the mass of cross-linked oligomers.
-
-    // 2. Each Coordinates item should be considered a residual chain
-    //(SelectionType is SELECTION_TYPE_RESIDUAL_CHAINS), thus only
-    // one item should see its left and right caps accounted for. This
-    // is typically the case when the user selects multiple regions
-    // like it would select repeated sequence elements in a polymer
-    // sequence: all the regions selected are treated as a single
-    // oligomer.
-
-    // Holds the number of times the chemical entities are to be
-    // accounted for.
-    int times = 0;
-    
-    if (mp_calcOptions->selectionType() == SELECTION_TYPE_RESIDUAL_CHAINS)
-      {
-	times = 1;
-// 	qDebug() << __FILE__ << __LINE__
-// 		  << "SELECTION_TYPE_RESIDUAL_CHAINS ; times:" << times;
-      }
-    else
-      {
-	times = mp_calcOptions->coordinateList().size();
-
-// 	qDebug() << __FILE__ << __LINE__
-// 		  << "SELECTION_TYPE_OLIGOMERS ; times:" << times;
-      }
-    
-    // Account for the left and right cap masses, if so required.
-
-    if (mp_calcOptions->capping() & MXT_CAP_LEFT)
-      {
-	formula.setFormula(polChemDef->leftCap());
-
-	// Incrementally account for the new formula in the same
-	// atomcount list in the formula.
-	if(formula.accountAtoms(atomRefList, times) == false)
-	  {
-	    setCursor(Qt::ArrowCursor);
-	  
-	    QMessageBox::warning 
-	     (0, 
-	       tr("massXpert - Compositions"),
-	       tr("Failed accounting left cap."),
-	       QMessageBox::Ok);
-	  
-	    return;
-	  }
-	
-// 	qDebug() << __FILE__ << __LINE__
-// 		  << "Formula after accounting left cap:"
-// 		  << formula.elementalComposition();
-      }
-    
-    if (mp_calcOptions->capping() & MXT_CAP_RIGHT)
-      {
-	formula.setFormula(polChemDef->rightCap());
-      
-	// Incrementally account for the new formula in the same
-	// atomcount list in the formula.
-	if(formula.accountAtoms(atomRefList, times) == false)
-	  {
-	    setCursor(Qt::ArrowCursor);
-	  
-	    QMessageBox::warning 
-	     (0, 
-	       tr("massXpert - Compositions"),
-	       tr("Failed accounting right cap."),
-	       QMessageBox::Ok);
-	  
-	    return;
-	  }
-	
-// 	qDebug() << __FILE__ << __LINE__
-// 		  << "Formula after accounting right cap:"
-// 		  << formula.elementalComposition();
-      }
-    
-    // Account for the left and right modification masses, if so
-    // required and the region(s) require(s) it: we have to make it
-    // clear if the selection encompasses indices 0(left end) and/or
-    // polymerSize-1(right end).
-    
-    if (mp_calcOptions->polymerEntities() & 
-	MXT_POLYMER_CHEMENT_LEFT_END_MODIF)
-      {
-	if(m_coordinateList.encompassIndex(0))
-	  {
-	    Modif modif =  mp_polymer->leftEndModif();
-      
-	    formula.setFormula(modif.formula());
-
-	    qDebug() << __FILE__ << __LINE__
-		      << "Accounting for left end modif:"
-		      << modif.name();
-	    
-	    // Incrementally account for the new formula in the same
-	    // atomcount list in the formula.
-	    if (formula.accountAtoms(atomRefList, 1) == false)
-	      {
-		setCursor(Qt::ArrowCursor);
-	  
-		QMessageBox::warning 
-		 (0, 
-		   tr("massXpert - Compositions"),
-		   tr("Failed accounting left end modification."),
-		   QMessageBox::Ok);
-	  
-		return;
-	      }
-
-// 	    qDebug() << __FILE__ << __LINE__
-// 		      << "Formula after accounting left end modif:"
-// 		      << formula.elementalComposition();
-	  }
-      }
-    
-    if (mp_calcOptions->polymerEntities() & 
-	MXT_POLYMER_CHEMENT_RIGHT_END_MODIF)
-      {
-	if(m_coordinateList.encompassIndex(mp_polymer->size() - 1))
-	  {
-	    Modif modif =  mp_polymer->rightEndModif();
-      
-	    formula.setFormula(modif.formula());
-
-// 	    qDebug() << __FILE__ << __LINE__
-// 		      << "Accounting for right end modif:"
-// 		      << modif.name();
-	    
-	    // Incrementally account for the new formula in the same
-	    // atomcount list in the formula.
-	    if (formula.accountAtoms(atomRefList, 1) == false)
-	      {
-		setCursor(Qt::ArrowCursor);
-	  
-		QMessageBox::warning 
-		 (0, 
-		   tr("massXpert - Compositions"),
-		   tr("Failed accounting right end modification."),
-		   QMessageBox::Ok);
-	  
-		return;
-	      }
-
-// 	    qDebug() << __FILE__ << __LINE__
-// 		      << "Formula after accounting right end modif:"
-// 		      << formula.elementalComposition();
-	  }
-      }
-
-    // At this point we should not forget if the user asks to take into
-    // account the cross-links... However, BE CAREFUL that cross-links
-    // can only be taken into account if all the partners of a given
-    // cross-link are actually encompassed into the selection.
-
-    if (mp_calcOptions->monomerEntities() & MXT_MONOMER_CHEMENT_CROSS_LINK)
-      {
-	const CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
-      
-	for(int iter = 0; iter < crossLinkList.size(); ++iter)
-	  {
-	    CrossLink *crossLink = crossLinkList.at(iter);
-	  
-	    if (crossLink->encompassedBy(m_coordinateList)
-		== MXP_CROSS_LINK_ENCOMPASSED_FULL)
-	      {
-		// The crossLink is fully encompassed by our monomer
-		// stretch, so we should take it into account.
-	      
-// 		qDebug() << __FILE__ << __LINE__
-// 			  << "Accounting for fully encompassed cross-link:"
-// 			  << crossLink->name();
-		
-		if(!crossLink->formula().isEmpty())
-		  {
-		    formula.setFormula(crossLink->formula());
-		  
-		    // qDebug() << __FILE__ << __LINE__ 
-		    // << "Cross-link formula:" << crossLink->formula();
-		  
-		    // Incrementally account for the new formula in the same
-		    // atomcount list in the formula.
-		    if (formula.accountAtoms(atomRefList, 1) == false)
-		      {
-			setCursor(Qt::ArrowCursor);
-		      
-			QMessageBox::warning 
-			 (0, 
-			   tr("massXpert - Compositions"),
-			   tr("%1@%\n"
-			       "Failed accounting for crossLink %3 "
-			       "with formula %4")
-			   .arg(__FILE__)
-			   .arg(__LINE__)
-			   .arg(crossLink->name())
-			   .arg(crossLink->formula()),
-			   QMessageBox::Ok);
-		      }
-		  }
-	      
-		// And now each modification that belongs to the
-		// crosslinker.
-	      
-		for(int jter = 0; 
-		     jter < crossLink->modifList().size(); 
-		     ++jter)
-		  {
-		    QString iterFormulaString = 
-		      crossLink->modifList().at(jter)->formula();
-		  
-		    // 		  qDebug() << __FILE__ << __LINE__ 
-		    // 			    << "Cross-link's modif formula:" 
-		    // 			    << iterFormulaString;
-		  
-		    formula.setFormula(iterFormulaString);
-		  
-		    // Incrementally account for the new formula in the same
-		    // atomcount list in the formula.
-		    if (formula.accountAtoms(atomRefList, 1) == false)
-		      {
-			setCursor(Qt::ArrowCursor);
-		      
-			QMessageBox::warning 
-			 (0, 
-			   tr("massXpert - Compositions"),
-			   tr("%1@%2\n"
-			       "Failed accounting for cross-link %3"
-			       "with modif formula %4")
-			   .arg(crossLink->name())
-			   .arg(crossLink->formula()),
-			   QMessageBox::Ok);
-		      
-			return;
-		      }
-		  }
-	      }
-	    // End of 
-	    // if (ret == MXP_CROSS_LINK_ENCOMPASSED_FULL)
-	  }
-	// End of
-	// for (int iter = 0; iter < crossLinkList->size(); ++iter)
-      }
-    // End of
-    // if (mp_calcOptions->monomerEntities() & MXT_MONOMER_CHEMENT_CROSS_LINK)
-  
-  
-    // The ionization rule. Do not forget to take into account the
-    // level!
-    formula.setFormula(mp_ionizeRule->formula());
-  
-    // Incrementally account for the new formula in the same
-    // atomcount list in the formula.
-    if (formula.accountAtoms(atomRefList, mp_ionizeRule->level()) == false)
-      {
-	setCursor(Qt::ArrowCursor);
-      
-	QMessageBox::warning 
-	 (0, 
-	   tr("massXpert - Compositions"),
-	   tr("Failed accounting ionization rule."),
-	   QMessageBox::Ok);
-      
-	return;
-      }
-  
-    m_ui.elementalCompositionLineEdit->
-      setText(formula.elementalComposition());
+    QString composition = mp_polymer->elementalComposition(*mp_ionizeRule,
+                                                           m_coordinateList,
+                                                           *mp_calcOptions);
+        m_ui.elementalCompositionLineEdit->
+      setText(composition);
 
     prepareResultsTxtString(MXP_TARGET_ELEMENTAL);
 
