@@ -607,12 +607,62 @@ namespace massXpert
 	return;
       }
 
-    // At this point, check if the fragmented monomer's side chain
-    // should contribute something to the mass of the fragment(usually
-    // one would expect that the contribution be negative, that is that
-    // the monomer gets decomposed somehow).
+    // At this point, check if the fragmented monomer should
+    // contribute something to the mass of the fragment (usually one
+    // would expect that the contribution be negative, that is that
+    // the monomer gets decomposed somehow). This integer value
+    // indicates if this monomer's mass should be added (positive
+    // integer) or removed (negative integer) and how may times it
+    // should thus be. The user is required to state what part of the
+    // monomer structure should be readded.
 
-    int sideChain = m_ui.sideChainContributionSpinBox->value();
+    // The rationale is that we can easily remove the mass of the
+    // whole monomer, which we know, of course. However, since full
+    // removal of a monomer mass does not make sense, the user should
+    // indicate which part of the monomer should be readded. This
+    // mechanism is typically used when making definitions of
+    // fragmentations which involve lateral chain decomposition (the
+    // base in DNA, the side chain for proteins and other chemical
+    // groups for sugars).
+
+    // For example, let's imagine, we are dealing with the
+    // decomposition of guanine in a DNA oligonucleotide. We want to
+    // define the fragmentation pattern 'a' with full decomposition of
+    // the base. 
+
+    // First off, the monomer of a DNA is constituted of two parts :
+
+    // 1. The skeleton, which does not change when the nucleotide
+    // changes (that is which is constant which ever the base is at
+    // any given monomer position), this is the sugar plus the
+    // phosphate (C5H8O5P);
+
+    // 2. The base, which changes each time a monomer changes (that's
+    // the lateral chain of the monomer). Adenine has formula C5H4N5,
+    // for example.
+
+    // Now, if we wanted to define the fragmentation a-B (that is a
+    // with base decomposition), we would define -O (that is the
+    // normal a fragmentation formula), +OH (as the left cap) and we
+    // would have to set two more parameters in order to remove the
+    // mass of the nitrogenous base (lateral chain).
+
+    // 1. Ask that the mass of the whole monomer be removed (set
+    // monomerContrib below to -1). But that would be removing too
+    // much stuff. We should now readd the mass of the skeleton, so
+    // that the net mass loss corresponds to decomposing only the base
+    // (adenine, for example).
+
+    // 2. Ask that the mass of the skeleton is readded. This is done
+    // by appending +C5H8O5P to the -O formula of the normal a
+    // fragmentation pattern.
+
+    // Finally, if we had to perform something similar wity protein,
+    // we would be having the same mechanism, unless the skeleton part
+    // of a proteinaceous residual chain is CH.
+
+
+    int monomerContrib = m_ui.monomerContributionSpinBox->value();
   
     // Now that all data were validated, we can set them all.
 
@@ -620,7 +670,7 @@ namespace massXpert
     fragSpec->setFragEnd(fragEnd);
     fragSpec->setFormula(editFormula);
     fragSpec->setComment(m_ui.fragSpecCommentLineEdit->text());
-    fragSpec->setSideChainContribution(sideChain);
+    fragSpec->setMonomerContribution(monomerContrib);
 
   
     // Update the list widget item.
@@ -908,8 +958,8 @@ namespace massXpert
 	else if (fragSpec->fragEnd() == MXT_FRAG_END_RIGHT)
 	  index = m_ui.fragEndComboBox->findText("RE");
 	m_ui.fragEndComboBox->setCurrentIndex(index);
-	m_ui.sideChainContributionSpinBox->setValue(fragSpec->
-						     sideChainContribution());
+	m_ui.monomerContributionSpinBox->setValue(fragSpec->
+						     monomerContribution());
 	m_ui.fragSpecCommentLineEdit->setText(fragSpec->comment());
       }
     else
@@ -918,7 +968,7 @@ namespace massXpert
 	m_ui.fragSpecFormulaLineEdit->setText("");
 	int index = m_ui.fragEndComboBox->findText("N/A");
 	m_ui.fragEndComboBox->setCurrentIndex(index);
-	m_ui.sideChainContributionSpinBox->setValue(0);
+	m_ui.monomerContributionSpinBox->setValue(0);
 	m_ui.fragSpecCommentLineEdit->setText("");
       } 
   }
@@ -957,10 +1007,10 @@ namespace massXpert
   {
     m_ui.fragSpecNameLineEdit->setText("");
     m_ui.fragSpecFormulaLineEdit->setText("");
-    m_ui.sideChainContributionSpinBox->setValue(0);
+    m_ui.monomerContributionSpinBox->setValue(0);
     int index = m_ui.fragEndComboBox->findText("N/A");
     m_ui.fragEndComboBox->setCurrentIndex(index);
-    m_ui.sideChainContributionSpinBox->setValue(0);
+    m_ui.monomerContributionSpinBox->setValue(0);
     m_ui.fragSpecCommentLineEdit->setText("");
 
     m_ui.fragRuleNameLineEdit->setText("");
