@@ -341,7 +341,7 @@ namespace massXpert
                                 "Failed accounting for formula '%3'.")
                              .arg(__FILE__)
                              .arg(__LINE__)
-                             .arg(formula.formula()));
+                             .arg(formula.text()));
         return;
       }
     
@@ -423,7 +423,7 @@ namespace massXpert
       {
         QString dlgName = m_name;
         dlgName.append(" + ( ");
-        dlgName.append(GlobElideText(formula.formula()));
+        dlgName.append(GlobElideText(formula.text()));
         dlgName.append(" )");
 
         MzLabInputOligomerTableViewDlg *dlg = 
