@@ -428,7 +428,7 @@ namespace massXpert
 				  "The formula '%3' is not valid.")
 			      .arg(__FILE__)
 			      .arg(__LINE__)
-			      .arg(formula.formula()));
+			      .arg(formula.text()));
 	return;
       }
 
