@@ -50,7 +50,7 @@
 namespace massXpert
 {
 
-  class MzLabInputOligomerTreeViewDlg;
+  class MzLabInputOligomerTableViewDlg;
   class MainWindow;
   class OligomerList;
   class OligomerPair;
@@ -69,14 +69,14 @@ namespace massXpert
         
     PolChemDef m_polChemDef;
     
-    QList<MzLabInputOligomerTreeViewDlg *> m_dlgList;
+    QList<MzLabInputOligomerTableViewDlg *> m_dlgList;
     MainWindow *mp_mainWindow;
 
     IonizeRule m_ionizeRule;
 
-    bool inputListDlg(MzLabInputOligomerTreeViewDlg **);
-    bool inputListsDlg(MzLabInputOligomerTreeViewDlg **,
-			MzLabInputOligomerTreeViewDlg **);
+    bool inputListDlg(MzLabInputOligomerTableViewDlg **);
+    bool inputListsDlg(MzLabInputOligomerTableViewDlg **,
+                       MzLabInputOligomerTableViewDlg **);
     
     void destroyDlg(const QString &);
 
@@ -88,12 +88,12 @@ namespace massXpert
     void applyThresholdPushButton();
     void incrementChargePushButton();
     void reionizePushButton();
-    void performMatchesPushButton();
+    void performMatchWorkPushButton();
     
     void deleteInputListItem();
     void inputListWidgetItemClicked(QListWidgetItem *);
 
-    void fillMolecularMassList(const OligomerList *, 
+    void fillMolecularMassList(const OligomerList &, 
 				QList<double> *,
 				MassType &);
     
@@ -118,12 +118,14 @@ namespace massXpert
     
     const IonizeRule &ionizeRule() const;
     
-    MzLabInputOligomerTreeViewDlg *findDlg(const QString &);
+    MzLabInputOligomerTableViewDlg *findDlg(const QString &);
+    MzLabInputOligomerTableViewDlg *newInputList(QString, MassType, bool);
 
     bool maybeSave();
 
   public slots:
-    MzLabInputOligomerTreeViewDlg *newInputList();
+    MzLabInputOligomerTableViewDlg *newInputList();
+    void help();
   };
 
 } // namespace massXpert
