@@ -1362,11 +1362,14 @@ namespace massXpert
     Q_ASSERT(ret);
   
     ret = scaleVignettes();
-    Q_ASSERT(ret);    
+    if (ret == 0)
+      qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
 
     mp_editorWnd->statusBar()->showMessage(tr("Positioning vignettes"));
     ret = positionVignettes();
-    Q_ASSERT(ret);
+    if (ret == 0)
+      qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
+    
     mp_editorWnd->statusBar()->showMessage(tr("Done positioning vignettes"));
 
     renderCursor();
@@ -1447,7 +1450,8 @@ namespace massXpert
   
     bool ret = false;
     ret = mp_polymer->insertMonomerAt(monomer, index);
-    Q_ASSERT(ret);
+    if (ret == 0)
+      qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
 
     m_monomerVignetteList.insert(index, monomerVignette);  
     scaleVignette(monomerVignette);
@@ -1618,12 +1622,14 @@ namespace massXpert
       return 0;
 
     bool result = prepareMonomerRemovalAt(index);
-    Q_ASSERT(result);
-    
+    if (result == 0)
+      qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
+
     result = mp_polymer->removeMonomerAt(index);
-    Q_ASSERT(result);
-  
-    // Get the pointer to the corresponding monomer vignette, so that we
+    if (result == 0)
+      qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
+
+        // Get the pointer to the corresponding monomer vignette, so that we
     // can remove it from the scene.
 
     removeVignetteAt(index);
