@@ -368,7 +368,6 @@ namespace massXpert
 	  QObject::tr("\nMulti-region selection enabled: no\n");
       }
     
-
     // If there are cross-links, list all of these.
 
     if (mpa_polymer->crossLinkList().size())
@@ -2782,7 +2781,37 @@ namespace massXpert
 				  QMessageBox::Ok);
 	return;
       }
+
+    if (m_calcOptions.monomerEntities() & MXT_MONOMER_CHEMENT_CROSS_LINK)
+      {
+        // Check what is the situation with respect to the cross-links,
+        // which, from a fragmentation standpoint are particularly
+        // difficult to handle. In particular, alert the user if the
+        // select oligomer has a partial cross-link (a cross-link that
+        // links on oligomer monomer to a monomer outside of that
+        // oligomer).
+
+        int startIndex = coordList[0]->start();
+        int endIndex = coordList[0]->end();
+
+        // Get the cross-links for the region.
+        QList<CrossLink *> crossLinkList;
+
+        int partials = 0;
     
+        mpa_polymer->crossLinkList(startIndex, endIndex, 
+                                   &crossLinkList, &partials);
+	  
+        if(partials)
+          {
+            QMessageBox::warning(this, tr("massxpert"),
+                                 tr("Fragmentation calculations do not\n"
+                                    "take into account partial cross-links.\n"
+                                    "These partial cross-links are ignored."),
+                                 QMessageBox::Ok);
+          }        
+      }
+        
     // No need to do this here, because the dialog window will have
     // its own calcOptions copy and will make this work anyway upon
     // initialization.
