@@ -78,9 +78,9 @@ namespace massXpert
     QMenu *fileImportMenu;
     QMenu *editMenu;
     QMenu *chemistryMenu;
-    QMenu *dataMiningMenu;
     QMenu *optionsMenu;
-
+    QMenu *calculatorMenu;
+    
     QAction *closeAct;
     QAction *saveAct;
     QAction *saveAsAct;
@@ -107,6 +107,9 @@ namespace massXpert
     
     QAction *decimalPlacesOptionsAct;
 
+    QAction *newCalculatorWholeSequenceMassesAct;
+    QAction *newCalculatorSelectedSequenceMassesAct;
+
     // Allocated but reparented to QStatusBar.
     QProgressBar *mp_progressBar;
   
@@ -184,10 +187,16 @@ namespace massXpert
     void getsFocus();
   
     void updateWholeSequenceMasses(bool = false);
+
+    void wholeSequenceMasses(double * = 0, double * = 0);
+    void selectedSequenceMasses(double * = 0, double * = 0);
+    
     void updateSelectedSequenceMasses(bool = false);
 
     void updatePolymerEndsModifs();
 
+    void newCalculator(QString, QString);
+    
   signals:
     void polymerSequenceModifiedSignal();
 				  
@@ -249,6 +258,9 @@ namespace massXpert
     void pkaPhPi();
 
     void decimalPlacesOptions();
+
+    void newCalculatorWholeSequenceMasses();
+    void newCalculatorSelectedSequenceMasses();
     
     void crossLinksPartiallyEncompassedSlot(int);
 
