@@ -76,18 +76,16 @@ namespace massXpert
   IsotopicPatternCalculator::IsotopicPatternCalculator
   (Formula formula,
    int charge,
-   double fwhm,
-   int maxPeaks,
+   int maxPeakCentroids,
    double minProb,
    const QList<Atom *> &atomRefList,
-   QString *outputString)
-  : m_formula(formula), 
-    m_charge(charge),
-    m_fwhm(fwhm),
-    m_maxPeaks(maxPeaks),
-    m_minProb(minProb),
-    m_atomRefList(atomRefList),
-    mp_outputString(outputString)
+   PeakShapeConfig config)
+    : m_formula(formula), 
+      m_charge(charge),
+      m_maxPeakCentroids(maxPeakCentroids),
+      m_minProb(minProb),
+      m_atomRefList(atomRefList),
+      m_config(config)
   {
     if(m_atomRefList.isEmpty())
       qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
@@ -98,10 +96,10 @@ namespace massXpert
     if(m_charge <= 0)
       qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
     
-    if(m_fwhm <= 0)
+    if(m_config.fwhm() <= 0)
       qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
     
-    if(m_maxPeaks < 1)
+    if(m_maxPeakCentroids < 1)
       qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
 
     m_sumProbabilities = 0;
@@ -143,7 +141,10 @@ namespace massXpert
 
   IsotopicPatternCalculator::~IsotopicPatternCalculator()
   {
-    clearFreePeakList();
+    freeClearPeakCentroidList();
+    freeClearTempPeakCentroidList();
+    freeClearPeakShapeList();
+    freeClearPointList();
   }
 
 
@@ -155,47 +156,97 @@ namespace massXpert
   }
   
   
-  const QList<IsotopicPeak *> &
-  IsotopicPatternCalculator::centroidPeakList() const
+  const QList<PeakCentroid *> &
+  IsotopicPatternCalculator::peakCentroidList() const
   {
-    return m_centroidPeakList;
+    return m_peakCentroidList;
+  }
+
+
+  const QList<QPointF *> &
+  IsotopicPatternCalculator::pointList() const
+  {
+    return m_pointList;
   }
   
 
-  void
-  IsotopicPatternCalculator::clearFreePeakList()
+  QString *
+  IsotopicPatternCalculator::peakCentroidListAsString() const
   {
-    while(!m_centroidPeakList.isEmpty())
-      delete m_centroidPeakList.takeFirst();
-  }
-  
-  
-  void
-  IsotopicPatternCalculator::clearFreeTempPeakList()
-  {
-    while(!m_tempPeakList.isEmpty())
-      delete m_tempPeakList.takeFirst();
+    QString *text = new QString();
+    
+    for(int iter = 0, size = m_peakCentroidList.size();
+        iter < size; ++iter)
+      {
+        PeakCentroid *peakCentroid = m_peakCentroidList.at(iter);
+        text->append(QString().setNum(peakCentroid->mz(), 'f', 6));
+        text->append(" ");
+        text->append(QString().setNum(peakCentroid->relativeIntensity(), 
+                                      'f', 15));
+        text->append("\n");
+      }
+    
+    return text;
   }
   
   
+
   bool 
-  IsotopicPatternCalculator::seedCentroidPeakList()
+  IsotopicPatternCalculator::seedPeakCentroidList()
   {
     // Let's seed all the calculations with the first centroid peak.
-    IsotopicPeak *firstPeak = new IsotopicPeak(0, 0, 0, 0);
-    firstPeak->setMass(0);
-    firstPeak->setProbability(1);
+    PeakCentroid *firstPeakCentroid = new PeakCentroid(0, 0, 0);
+    firstPeakCentroid->setMz(0);
+    firstPeakCentroid->setProbability(1);
     
-    clearFreePeakList();
+    freeClearPeakCentroidList();
     
-    m_centroidPeakList.append(firstPeak);
+    m_peakCentroidList.append(firstPeakCentroid);
 
     return true;
   }
   
 
+  void
+  IsotopicPatternCalculator::freeClearPeakCentroidList()
+  {
+    while(!m_peakCentroidList.isEmpty())
+      delete m_peakCentroidList.takeFirst();
+  }
+  
+  
+  void
+  IsotopicPatternCalculator::freeClearTempPeakCentroidList()
+  {
+    while(!m_tempPeakCentroidList.isEmpty())
+      delete m_tempPeakCentroidList.takeFirst();
+
+    m_tempPeakCentroidList.clear();
+  }
+  
+  
+  void
+  IsotopicPatternCalculator::freeClearPeakShapeList()
+  {
+    while(!m_peakShapeList.isEmpty())
+      delete m_peakShapeList.takeFirst();
+
+    m_peakShapeList.clear();
+  }
+  
+  
+  void
+  IsotopicPatternCalculator::freeClearPointList()
+  {
+    while(!m_pointList.isEmpty())
+      delete m_pointList.takeFirst();
+
+    m_pointList.clear();
+  }
+  
+  
   int
-  IsotopicPatternCalculator::calculateCentroidPeakList()
+  IsotopicPatternCalculator::calculatePeakCentroids()
   {
     // Get a shortcut handle to the list of AtomCount object that were
     // set in the formula during the validation in the constructor
@@ -209,9 +260,9 @@ namespace massXpert
     // sequence. That is handled in the function call
     // accountAtomCount() below.
 
-    clearFreeTempPeakList();
+    freeClearTempPeakCentroidList();
 
-    seedCentroidPeakList();
+    seedPeakCentroidList();
     
     // Set the m_progressValue to 0, as we are going to make a
     // calculation. Each time 10 new isotopes are added, we increment
@@ -261,6 +312,232 @@ namespace massXpert
   }
   
 
+  int 
+  IsotopicPatternCalculator::calculatePeakShapes()
+  {
+    // Once all the peak centroids have been computed, it necessary to
+    // produce the peak shapes for each one.
+
+    if(m_peakCentroidList.isEmpty())
+      {
+        int res = calculatePeakCentroids();
+    
+        if(!res)
+          return 0;
+      }
+    
+    for (int iter = 0, peakCentroidListSize = m_peakCentroidList.size();
+         iter < peakCentroidListSize; ++iter)
+      {
+        PeakCentroid *peakCentroid = m_peakCentroidList.at(iter);
+        
+	double mz = peakCentroid->mz();
+	double relInt = peakCentroid->relativeIntensity();
+        
+        PeakShape *peakShape = new PeakShape(mz, 
+                                             relInt,
+                                             0 /* probability */,
+                                             m_config);
+                
+        peakShape->calculatePeakShape();
+
+        m_peakShapeList.append(peakShape);
+      }
+
+    return m_peakShapeList.size();
+  }
+  
+
+  const QList<QPointF *>  &
+  IsotopicPatternCalculator::sumPeakShapes()
+  {
+    // Clear the point list.
+    freeClearPointList();
+    
+    // Make sure that we have computed each individual peak shape for
+    // the centroids. If not, then do it first.
+
+    int peakShapeListSize = m_peakShapeList.size();
+
+    if(!peakShapeListSize)
+      {
+        if(!calculatePeakShapes())
+          return m_pointList;
+
+        peakShapeListSize = m_peakShapeList.size();
+      }
+    
+    // At this point, each centroid peak, that is each
+    // mzRatio/intensity pair in m_peakCentroidList has given rise to
+    // a full gaussian/lorentzian curve that's been appended in the
+    // list of peak shapes.
+
+    // We now have to perform the sum of all these peak shapes so as
+    // to generate a single (x,y) curve that encompasses all of the
+    // isotopic cluster.
+
+    // We need to know the min and max mzRatio values of all the
+    // curves.
+
+    // Peak shapes should be generated from left to right in the
+    // pointList spectral view, that is from lowest mz to higest
+    // mz. So, logically, the first point of the first peak shape
+    // should be the point of lowest mz. Likewise, the last point of
+    // the last peak shape should be the highest mz.
+    
+    PeakShape *peakShape = 0;
+    QPointF *point = 0;
+    
+    // Get first point of the first peakShape and its x value.
+
+    peakShape = m_peakShapeList.first();
+    point = peakShape->pointList().first();
+    double minMz = point->x();
+    
+    peakShape = m_peakShapeList.last();
+    point = peakShape->pointList().last();
+    double maxMz = point->x();
+
+
+#ifdef NOT_DEFINED
+
+    // Old version that is more CPU-consuming.
+
+    double tempMz = 0;
+    double maxMz = 0;
+    double minMz = 1000000000;
+
+    for(int iter = 0; iter < peakShapeListSize ; ++iter)
+      {
+        PeakShape *peakShape = m_peakShapeList.at(iter);
+      
+        // Get to the list of points in the peak shape
+        const QList<QPointF *> &peakCentroidList = peakShape->pointList();
+        
+        // Get first point of the peakShape.
+        QPointF *point = peakCentroidList.first();
+
+        // Get the minimum mz
+        tempMz = point->x();
+      
+        if(tempMz < minMz)
+          minMz = tempMz;
+
+        // Get last point of the peakShape.
+        point = peakCentroidList.last();
+
+        // Get the maximum mz
+        tempMz = point->x();
+      
+        if(tempMz > maxMz)
+          maxMz = tempMz;
+      }
+#endif
+
+    // At this point we know that our mass point list (the spectral
+    // view of the isotopic cluster) should range [minMz -- maxMz]. We
+    // can perform the actual sum of all the peak shapes. The result
+    // of the sum should go into the spectral list of points.
+
+    double curMz = minMz;
+  
+    while(curMz <= maxMz)
+      {
+        // curMz now has a mz value for which we have to sum all the
+        // intensities in each curve.
+      
+        double summedIntensity = 0;
+      
+        for(int iter = 0; iter < peakShapeListSize ; ++iter)
+          {
+            PeakShape *peakShape = m_peakShapeList.at(iter);
+          
+            bool ok = false;
+          
+            summedIntensity += peakShape->intensityAt(curMz, 
+                                                      m_config.increment(),
+                                                      &ok);
+          }
+      
+        QPointF *point = new QPointF(curMz, summedIntensity);
+        
+        m_pointList.append(point);
+
+        curMz += m_config.increment();
+      }
+    
+    return m_pointList;
+  }
+  
+  
+  QString *
+  IsotopicPatternCalculator::pointListAsString() const
+  {
+    QString *text = new QString();
+    
+    for(int iter = 0, size = m_pointList.size();
+        iter < size ; ++iter)
+      {
+        QPointF *point = m_pointList.at(iter);
+        
+        text->append(QString().setNum(point->x(), 'f', 10));
+        text->append(" ");
+        text->append(QString().setNum(point->y(), 'f', 10));
+        text->append("\n");
+      }
+    
+    return text;
+  }
+  
+  
+  QList<QPointF *> *
+  IsotopicPatternCalculator::duplicatePointList() const
+  {
+    QList<QPointF *> *pointList = new QList<QPointF *>;
+    
+    for(int iter = 0, size = m_pointList.size();
+        iter < size ; ++iter)
+      {
+        QPointF *point = new QPointF(*(m_pointList.at(iter)));
+        pointList->append(point);
+      }
+    
+    return pointList;
+  }
+  
+
+  int
+  IsotopicPatternCalculator::transferPoints(QList<QPointF *> *pointList)
+  {
+    if(!pointList)
+      qFatal("Fatal error at %s@%d.Aborting.", __FILE__, __LINE__);
+
+    int count = 0;
+    
+    while(m_pointList.size())
+      {
+        pointList->append(m_pointList.takeFirst());
+        ++count;
+      }
+    
+    return count;
+  }
+  
+  
+  QPointF *
+  IsotopicPatternCalculator::firstPoint() const
+  {
+    return m_pointList.first();
+  }
+  
+
+  QPointF *
+  IsotopicPatternCalculator::lastPoint() const
+  {
+    return m_pointList.last();
+  }
+  
+
   int
   IsotopicPatternCalculator::accountAtomCount(const AtomCount *atomCount)
   {
@@ -284,7 +561,7 @@ namespace massXpert
 
     // qDebug() << __FILE__ << __LINE__
     //          << message
-    //          << "m_centroidPeakList size:" << m_centroidPeakList.size();
+    //          << "m_peakCentroidList size:" << m_peakCentroidList.size();
     
     int count = atomCount->count();
     
@@ -297,7 +574,7 @@ namespace massXpert
            m_aborted)
           break;
                   
-        updatePeakListWithAtom(atomCount);
+        updatePeakCentroidListWithAtom(atomCount);
         
         // Each time a new atomCount count is dealt with, we increment
         // that progress report value and emit a signal so that the
@@ -309,7 +586,7 @@ namespace massXpert
 
     // qDebug() << __FILE__ << __LINE__
     //          << "Done accouting atomCount" << atomCount->symbol()
-    //          << "m_centroidPeakList size:" << m_centroidPeakList.size();
+    //          << "m_peakCentroidList size:" << m_peakCentroidList.size();
     
     // return the number of atomCount instances actually accounted
     // for.
@@ -318,7 +595,7 @@ namespace massXpert
   
 
   int
-  IsotopicPatternCalculator::updatePeakListWithAtom(const Atom *atom)
+  IsotopicPatternCalculator::updatePeakCentroidListWithAtom(const Atom *atom)
   {
    if(!atom)
       qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
@@ -327,99 +604,99 @@ namespace massXpert
     // with the mass and probability of each isotope of the new
     // atom. Each time a peak in the peak list is incremented, we'll
     // create a brand new peak that we'll set in a new peak list
-    // called m_tempPeakList.
+    // called m_tempPeakCentroidList.
 
-   for (int iter = 0, peakCount = m_centroidPeakList.size();
+   for (int iter = 0, peakCount = m_peakCentroidList.size();
         iter < peakCount ; ++iter)
      {
-       IsotopicPeak *centroidPeak = m_centroidPeakList.at(iter);
+       PeakCentroid *peakCentroid = m_peakCentroidList.at(iter);
        
        for(int jter = 0, isotopeCount = atom->isotopeList().size() ;
            jter < isotopeCount; ++jter)
          {
            Isotope *isotope = atom->isotopeList().at(jter);
            
-           updatePeakWithIsotope(centroidPeak, isotope);
+           updatePeakCentroidWithIsotope(peakCentroid, isotope);
          }
      }
    
    // Now that we have updated all the centroid peaks with all the
    // isotopes of the atom, we can make some housekeeping work. In
    // particular, when doing the updating of all the isotopic peaks
-   // in m_centroidPeakList, we actually created a new list of
+   // in m_peakCentroidList, we actually created a new list of
    // peaks. We want to get rid of all the old peaks and set the
-   // m_centroidPeakList reference to point to the new list of peaks.
+   // m_peakCentroidList reference to point to the new list of peaks.
    
-   clearFreePeakList();
+   freeClearPeakCentroidList();
    
-   m_centroidPeakList = m_tempPeakList;
-   m_tempPeakList.clear();
+   m_peakCentroidList = m_tempPeakCentroidList;
+   m_tempPeakCentroidList.clear();
    
-   mergePeaksWithSameMasses();
+   mergePeakCentroidsWithSameMz();
    
-   removePeaksInExcess();
+   removePeakCentroidsInExcess();
    
-   return m_centroidPeakList.size();
+   return m_peakCentroidList.size();
   }
   
 
   int
-  IsotopicPatternCalculator::updatePeakWithIsotope(IsotopicPeak *centroidPeak,
-                                                   const Isotope *isotope)
+  IsotopicPatternCalculator::updatePeakCentroidWithIsotope
+  (PeakCentroid *peakCentroid,
+   const Isotope *isotope)
   {
-    if(!centroidPeak)
+    if(!peakCentroid)
       qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
  
     if(!isotope)
       qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
  
-    IsotopicPeak *newPeak = 
-      new IsotopicPeak(centroidPeak->mass() +
+    PeakCentroid *newPeakCentroid = 
+      new PeakCentroid(peakCentroid->mz() +
                        isotope->mass() / m_charge,
                        0,
-                       centroidPeak->probability() *
-                       (isotope->abundance() / 100),
-                       0);
+                       peakCentroid->probability() *
+                       (isotope->abundance() / 100));
                 
     // Get the mass of the new peak. We'll use it massively later.
-    double newPeakMass = newPeak->mass();
+    double newPeakCentroidMz = newPeakCentroid->mz();
     
-    if (m_tempPeakList.isEmpty())
+    if (m_tempPeakCentroidList.isEmpty())
       {
-        // First iteration, the m_tempPeakList is empty, thus simply
+        // First iteration, the m_tempPeakCentroidList is empty, thus simply
         // append to the list the newly allocated peak list instance.
 
-        m_tempPeakList.append(newPeak);
+        m_tempPeakCentroidList.append(newPeakCentroid);
                         
         // qDebug() << "Appended new peak:"
-        //          << newPeak->mass() << "--"
-        //          << newPeak->probability();
+        //          << newPeakCentroid->mass() << "--"
+        //          << newPeakCentroid->probability();
       }
-    else // m_tempPeakList is not empty
+    else // m_tempPeakCentroidList is not empty
       {
-        // The m_tempPeakList has items in it. We want to insert the
+        // The m_tempPeakCentroidList has items in it. We want to insert the
         // newly allocated peak at the proper location, mass-based,
         // that is right after the peak item that has a mass just less
         // than ours.
 
         bool inserted = false;
         
-        for(int iter = 0; iter < m_tempPeakList.size(); ++iter)
+        for(int iter = 0; iter < m_tempPeakCentroidList.size(); ++iter)
           {
-            IsotopicPeak *iteratedPeak = 
-              m_tempPeakList.at(iter);
+            PeakCentroid *iteratedPeakCentroid = 
+              m_tempPeakCentroidList.at(iter);
 		
             // The iterated peak has a mass greater than ours, thus go
             // on to next iteration.
-            if (newPeakMass > iteratedPeak->mass())
+            if (newPeakCentroidMz > iteratedPeakCentroid->mz())
               continue;
 			  
             // Ah, finally, we found a place to insert our peak.
-            m_tempPeakList.insert(iter, newPeak);
+            m_tempPeakCentroidList.insert(iter, newPeakCentroid);
                             
             // qDebug() << "Inserted new peak:"
-            //          << newPeak->mass() << "--"
-            //          << newPeak->probability();
+            //          << newPeakCentroid->mass() << "--"
+            //          << newPeakCentroid->probability();
                             
             inserted = true;
 
@@ -431,11 +708,11 @@ namespace massXpert
         // list... Thus append the peak.
         if(!inserted)
           {
-            m_tempPeakList.append(newPeak);
+            m_tempPeakCentroidList.append(newPeakCentroid);
                             
             // qDebug() << "Appended peak:"
-            //          << newPeak->mass() << "--"
-            //          << newPeak->probability();	  
+            //          << newPeakCentroid->mass() << "--"
+            //          << newPeakCentroid->probability();	  
           }
         else
           {
@@ -445,13 +722,13 @@ namespace massXpert
 		      
         // qDebug() << "List of peaks:";
         //
-        // for (int zter = 0; zter < m_tempPeakList.size(); ++zter)
-        //   qDebug() << m_tempPeakList.at(zter)->mass()
+        // for (int zter = 0; zter < m_tempPeakCentroidList.size(); ++zter)
+        //   qDebug() << m_tempPeakCentroidList.at(zter)->mass()
         //            << "--" 
-        //            << m_tempPeakList.at(zter)->probability();
+        //            << m_tempPeakCentroidList.at(zter)->probability();
       }
     // End of
-    // else m_tempPeakList is not empty
+    // else m_tempPeakCentroidList is not empty
 
     // So we have dealt with one isotope. Just return.
 
@@ -459,20 +736,20 @@ namespace massXpert
   }
   
   int 
-  IsotopicPatternCalculator::mergePeaksWithSameMasses()
+  IsotopicPatternCalculator::mergePeakCentroidsWithSameMz()
   {
     // There might be some peaks very near one to the other in mass in
-    // the m_centroidPeakList. Our criterium to "merge" two peaks
+    // the m_peakCentroidList. Our criterium to "merge" two peaks
     // which are too near in mass is that if the masses differ by less
     // than the FWHM, then we'll merge them adding the probabilities
     // together.
 
     int removedPeaks = 0;
 
-    for (int iter = 0; iter < m_centroidPeakList.size() - 1; ++iter)
+    for (int iter = 0; iter < m_peakCentroidList.size() - 1; ++iter)
       {
-        IsotopicPeak *curPeak = m_centroidPeakList.at(iter);
-        IsotopicPeak *nextPeak = m_centroidPeakList.at(iter + 1);
+        PeakCentroid *curPeakCentroid = m_peakCentroidList.at(iter);
+        PeakCentroid *nextPeakCentroid = m_peakCentroidList.at(iter + 1);
         
         // qDebug() << __FILE__ << __LINE__ << "\n"
         //          << "\tCentroid peak at" << iter 
@@ -480,21 +757,27 @@ namespace massXpert
         //          << "\tCentroid peak at" << (iter + 1)
         //          << ":" << nextPeak->mass() << "\n";
                   
-        double absDiff = fabs(curPeak->mass() - nextPeak->mass());
-	      
+        double absDiff = 
+          fabs(curPeakCentroid->mz() - nextPeakCentroid->mz());
+        
         // qDebug() << __FILE__ << __LINE__ << "\n"
         //          << "\tabsDiff is" << absDiff << "with m_fwhm:" << m_fwhm;
         
-        if(absDiff <= m_fwhm)
+        // This dividing m_fwhm by three was added to successfully fix
+        // the calculation bug that would center the shape of a
+        // non-resolved mass peak (too low a resolution setting) at a
+        // mass very much less than average mass !
+        if(absDiff <= m_config.fwhm() / 3)
           {
 		  
             // Remove the forward (next) peak that is too close to
             // current one, but do not forget to account for that one
             // from the abundance point of vue.
             
-            curPeak->incrementProbability(nextPeak->probability());
+            curPeakCentroid->incrementProbability
+              (nextPeakCentroid->probability());
 
-            delete m_centroidPeakList.takeAt(iter + 1);
+            delete m_peakCentroidList.takeAt(iter + 1);
 
             // qDebug() << __FILE__ << __LINE__ << "\n"
             //          << "\nRemoved mass-similar peak.";
@@ -510,23 +793,23 @@ namespace massXpert
   
   
   int 
-  IsotopicPatternCalculator::removePeaksInExcess()
+  IsotopicPatternCalculator::removePeakCentroidsInExcess()
   {
     // The maximum number of peaks that are allowed by the user is
     // m_maxPeaks. Remove all the peaks that are found in the
-    // m_centroidPeakList after that count.
+    // m_peakCentroidList after that count.
     
     int removedPeaks = 0;
     
-    int peakCount = m_centroidPeakList.size();
+    int peakCount = m_peakCentroidList.size();
 
     // qDebug() << __FILE__ << __LINE__ << "\n"
-    //          << "\tm_centroidPeakList size:" << peakCount
+    //          << "\tm_peakCentroidList size:" << peakCount
     //          << "and m_maxPeaks is:" << m_maxPeaks;
     
-    while(peakCount > m_maxPeaks)
+    while(peakCount > m_maxPeakCentroids)
       {
-        delete m_centroidPeakList.takeLast();
+        delete m_peakCentroidList.takeLast();
 
         // qDebug() << __FILE__ << __LINE__ << "\n"
         //          << "\tRemoved peak.";
@@ -543,12 +826,12 @@ namespace massXpert
   int
   IsotopicPatternCalculator::calculateSumOfProbabilities()
   {
-    IsotopicPeak *isotopicPeak = 0;
+    PeakCentroid *peakCentroid = 0;
     int count = 0;
     
-    foreach (isotopicPeak, m_centroidPeakList)
+    foreach (peakCentroid, m_peakCentroidList)
       {
-        double probability = isotopicPeak->probability();
+        double probability = peakCentroid->probability();
         
 	m_sumProbabilities += probability;
         
@@ -566,16 +849,16 @@ namespace massXpert
   {
     calculateSumOfProbabilities();
     
-    for (int iter = 0, peakCount = m_centroidPeakList.size();
+    for (int iter = 0, peakCount = m_peakCentroidList.size();
          iter < peakCount; ++iter)
       {
-	IsotopicPeak *isotopicPeak = m_centroidPeakList.at(iter);
+	PeakCentroid *peakCentroid = m_peakCentroidList.at(iter);
       
 	double relativeIntensity = 
-          (isotopicPeak->probability() / m_greatestProbability) * 100;
+          (peakCentroid->probability() / m_greatestProbability) * 100;
         
 	if(relativeIntensity > std::numeric_limits<double>::min())
-	  isotopicPeak->setRelativeIntensity(relativeIntensity);
+	  peakCentroid->setRelativeIntensity(relativeIntensity);
       }
 
     return 1;
@@ -585,25 +868,25 @@ namespace massXpert
   int 
   IsotopicPatternCalculator::removeTooLowProbPeaks()
   {
-    int peakCount = m_centroidPeakList.size();
+    int peakCount = m_peakCentroidList.size();
     
     if(!peakCount)
       return 1;
     
     for(int iter = peakCount - 1; iter >= 0 ; --iter)
       {
-        IsotopicPeak *isotopicPeak = m_centroidPeakList.at(iter);
+        PeakCentroid *peakCentroid = m_peakCentroidList.at(iter);
 
-	if(isotopicPeak->probability() < m_minProb)
+	if(peakCentroid->probability() < m_minProb)
           {
             // The peak has too low a probability. Remove it.
 
             // qDebug() << __FILE__ << __LINE__
             //          << "Removing too low prob peak at: " << iter
-            //          << "With mass:" << isotopicPeak->mass()
-            //          << "Prob:" << isotopicPeak->probability();
+            //          << "With mass:" << peakCentroid->mass()
+            //          << "Prob:" << peakCentroid->probability();
             
-            delete m_centroidPeakList.takeAt(iter);
+            delete m_peakCentroidList.takeAt(iter);
           }
       }
   
@@ -733,7 +1016,7 @@ namespace massXpert
 
   int calculate_peaks(){
     compound *c;
-    isotope *newPeakList,*p,*i,*np1;
+    isotope *newPeakCentroidList,*p,*i,*np1;
     int amount;
 
     if(!(m_peakList=malloc(sizeof(isotope))))
@@ -747,10 +1030,10 @@ namespace massXpert
       {
 	for(amount = 0; amount < c->amount; ++amount)
 	  {
-	    if (!(newPeakList=malloc(sizeof(isotope))))
+	    if (!(newPeakCentroidList=malloc(sizeof(isotope))))
 	      return 0;
 	  
-	    newPeakList->mass = 0;
+	    newPeakCentroidList->mass = 0;
 	  
 	    for (p = m_peakList; p; p = p->next)
 	      {
@@ -764,15 +1047,16 @@ namespace massXpert
 		    np1->mass=p->mass + i->mass;
 		    np1->p=p->p * i->p;
 		  
-		    if(!(newPeakList = add_peak(newPeakList,np1)))
+		    if(!(newPeakCentroidList = 
+                         add_peak(newPeakCentroidList,np1)))
 		      return 0;
 		  }
 	      }
-	  
+            
 	    free_list(m_peakList);
-	    m_peakList = newPeakList;
+	    m_peakList = newPeakCentroidList;
 	    summarize_peaks();
-	  
+            
 	    if (fast_calc)
 	      cut_peaks(m_peakList);
 	  }
