@@ -1002,7 +1002,8 @@ namespace massXpert
 
     int index = -1;
     index = isCodeInList(m_code, refList, &other);
-    Q_ASSERT(index != -1);
+    if (index == -1)
+      qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
   
     // Mold this monomer.
     mold(other);
@@ -1077,7 +1078,8 @@ namespace massXpert
 
     int index = -1;
     index = isCodeInList(m_code, refList, &other);
-    Q_ASSERT(index != -1);
+    if (index == -1)
+      qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
   
     // Mold this monomer.
     mold(other);
