@@ -200,6 +200,19 @@ namespace massXpert
   }
 
 
+  Oligomer::Oligomer(const Ionizable& ionizable,
+                     const CalcOptions &calcOptions,
+                     int startIndex, int endIndex)
+    : Ionizable(ionizable), mp_polymer(0), 
+      m_calcOptions(calcOptions)
+  {
+    setStartEndIndices(startIndex, endIndex);
+    if (startIndex < 0)
+      qDebug() << __FILE__ << __LINE__
+               << "Construct with startIndex:" << startIndex;
+  }
+
+
   //! Constructs an oligomer.
   /*! 
   
@@ -443,6 +456,16 @@ namespace massXpert
     return m_calcOptions;
   }
   
+  void 
+  Oligomer::updateCalcOptions()
+  {
+    // The data that need update are the CoordinateList elements
+    // depending on the internal ::OligomerList data.
+
+    m_calcOptions.setCoordinateList(*(static_cast<CoordinateList *>(this)));
+  }
+  
+
 
   const Monomer &
   Oligomer::atLeftEnd() const
@@ -503,6 +526,48 @@ namespace massXpert
   }
 
 
+  // ELEMENTAL CALCULATION FUNCTION
+  /////////////////////////////////
+  
+  QString 
+  Oligomer::elementalComposition()
+  {
+    int times = 0;
+    
+    if (m_calcOptions.selectionType() == SELECTION_TYPE_RESIDUAL_CHAINS)
+      {
+	times = 1;
+
+        // qDebug() << __FILE__ << __LINE__
+        //          << "SELECTION_TYPE_RESIDUAL_CHAINS ; times:" << times;
+      }
+    else
+      {
+        // 	times = CoordinateList::size();
+
+        // Use the version whereby we can perform a sanity check that
+        // m_calcOptions was updated with the proper CoordinateList
+        // data.
+
+        times = m_calcOptions.coordinateList().size();
+        if(times != CoordinateList::size())
+          qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
+
+        // qDebug() << __FILE__ << __LINE__
+        //          << "SELECTION_TYPE_OLIGOMERS ; times:" << times;
+      }
+
+    return mp_polymer->elementalComposition
+      (m_ionizeRule,
+       *(static_cast<CoordinateList *>(this)),
+       m_calcOptions);
+  }
+  
+  
+  /////////////////////////////////
+  // ELEMENTAL CALCULATION FUNCTION
+  
+
   int
   Oligomer::makeMonomerText()
   {
