@@ -123,6 +123,10 @@ namespace massXpert
              const CalcOptions & = CalcOptions(),
              int = -1, int = -1);
     
+    Oligomer(const Ionizable &,
+             const CalcOptions & = CalcOptions(),
+             int = -1, int = -1);
+    
     Oligomer(Polymer *, const QString & = QString(),
              double = 0, double = 0, int = -1, int = -1, 
              const CalcOptions & = CalcOptions());
@@ -152,6 +156,7 @@ namespace massXpert
 
     void setCalcOptions(const CalcOptions &);
     const CalcOptions &calcOptions() const;
+    void updateCalcOptions();
     
     const Monomer &atLeftEnd() const;
     const Monomer &atRightEnd() const;
@@ -160,6 +165,14 @@ namespace massXpert
     QList<CrossLink*> *crossLinkList();
     bool addCrossLink(CrossLink *);
   
+    // ELEMENTAL CALCULATION FUNCTION
+    /////////////////////////////////
+    
+    QString elementalComposition();
+    
+    /////////////////////////////////
+    // ELEMENTAL CALCULATION FUNCTION
+
     virtual int makeMonomerText();
     QString *monomerText();
 
